@@ -3,6 +3,7 @@ import os
 from datetime import datetime
 from liquidluck.utils import import_module
 from liquidluck.namespace import ns
+from liquidluck import logger
 
 
 def detect_reader(filepath):
@@ -32,8 +33,11 @@ class Reader(object):
     def start(self):
         return None
 
-    def get_resource_path(self):
-        return self.filepath
+    def get_relative_folder(self):
+        postdir = os.path.join(ns.storage.projectdir,
+                               ns.site.postdir)
+        folder, filename = os.path.split(self.filepath.replace(postdir, ''))
+        return folder.lstrip('/')
 
     def get_resource_basename(self):
         folder, filename = os.path.split(self.filepath)
@@ -43,10 +47,27 @@ class Reader(object):
     def get_resource_destination(self):
         _format = ns.site.format
         post = self.parse_post()
-        filename = self.get_resource_basename() + '.html'
+        if hasattr(post, 'ext'):
+            filename = self.get_resource_basename() + '.' + post.ext
+        else:
+            filename = self.get_resource_basename() + '.html'
         year = str(post.date.year)
         month = str(post.date.month)
         day = str(post.date.day)
+        if '/' in _format:
+            path = ''
+            dates = {'year': year, 'month': month, 'day': day}
+            for attr in _format.split('/'):
+                if attr in dates:
+                    path = os.path.join(path, dates[attr])
+                elif attr:
+                    try:
+                        path = os.path.join(path, getattr(post, attr))
+                    except AttributeError:
+                        logger.warn('Attribute %s Missing: %s'\
+                                    % (attr, filename))
+                        pass
+            return os.path.join(path, filename)
         if _format == 'year':
             return os.path.join(year, filename)
         if _format == 'month':
@@ -55,10 +76,10 @@ class Reader(object):
             return os.path.join(year, month, day, filename)
         if hasattr(post, 'folder'):
             return os.path.join(post.folder, filename)
-        return filename
+        return os.path.join(self.get_relative_folder(), filename)
 
     def get_resource_slug(self):
-        return self.get_resource_destination()
+        return self.get_resource_destination().lower()
 
     def support_type(self):
         return None
@@ -74,12 +95,33 @@ class Reader(object):
                     return True
         return False
 
+    def _parse_datetime(sef, value):
+        supported_formats = [
+            '%a %b %d %H:%M:%S %Y',
+            '%Y-%m-%d %H:%M:%S',
+            '%Y-%m-%d %H:%M',
+            '%Y-%m-%dT%H:%M',
+            '%Y%m%d %H:%M:%S',
+            '%Y%m%d %H:%M',
+            '%Y-%m-%d',
+            '%Y%m%d',
+        ]
+        for format in supported_formats:
+            try:
+                return datetime.strptime(value, format)
+            except ValueError:
+                pass
+        logger.error('Unrecognized date/time: %r' % value)
+        raise ValueError('Unrecognized date/time: %r' % value)
+
     def render(self):
         try:
             post = self.parse_post()
-        except:
+        except Exception as e:
+            logger.error(e)
             ns.storage.errors.append(self.filepath)
             return None
+
         if not post or not post.get('date', None):
             ns.storage.errors.append(self.filepath)
             return None
@@ -87,20 +129,19 @@ class Reader(object):
         if not post.get('author', None):
             post.author = ns.context.get('author', 'admin')
 
-        dateformat = ns.site.dateformat
-        timeformat = ns.site.timeformat
         try:
-            post.date = datetime.strptime(post.get('date'), dateformat)
-        except ValueError:
-            post.date = datetime.strptime(post.get('date'), timeformat)
-        except ValueError:
+            post.date = self._parse_datetime(post.get('date'))
+        except ValueError as e:
             ns.storage.errors.append(self.filepath)
             return None
+
         for key in post.keys():
-            if '_date' in key:
-                post[key] = datetime.strptime(post[key], dateformat)
-            elif '_time' in key:
-                post[key] = datetime.strptime(post[key], timeformat)
+            if '_date' in key or '_time' in key:
+                try:
+                    post[key] = self._parse_datetime(post[key])
+                except ValueError as e:
+                    ns.storage.errors.append(self.filepath)
+                    return None
 
         if post.get('public', 'true') == 'false':
             post.public = False
